summaryrefslogtreecommitdiffstats
path: root/models/issues/issue_xref.go
diff options
context:
space:
mode:
Diffstat (limited to 'models/issues/issue_xref.go')
-rw-r--r--models/issues/issue_xref.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/models/issues/issue_xref.go b/models/issues/issue_xref.go
index 21ee24210f..a1086f9e81 100644
--- a/models/issues/issue_xref.go
+++ b/models/issues/issue_xref.go
@@ -277,26 +277,26 @@ func CommentTypeIsRef(t CommentType) bool {
return t == CommentTypeCommentRef || t == CommentTypePullRef || t == CommentTypeIssueRef
}
-// RefCommentHTMLURL returns the HTML URL for the comment that created this reference
-func (c *Comment) RefCommentHTMLURL() string {
+// RefCommentLink returns the relative URL for the comment that created this reference
+func (c *Comment) RefCommentLink() string {
// Edge case for when the reference is inside the title or the description of the referring issue
if c.RefCommentID == 0 {
- return c.RefIssueHTMLURL()
+ return c.RefIssueLink()
}
if err := c.LoadRefComment(); err != nil { // Silently dropping errors :unamused:
log.Error("LoadRefComment(%d): %v", c.RefCommentID, err)
return ""
}
- return c.RefComment.HTMLURL()
+ return c.RefComment.Link()
}
-// RefIssueHTMLURL returns the HTML URL of the issue where this reference was created
-func (c *Comment) RefIssueHTMLURL() string {
+// RefIssueLink returns the relative URL of the issue where this reference was created
+func (c *Comment) RefIssueLink() string {
if err := c.LoadRefIssue(); err != nil { // Silently dropping errors :unamused:
log.Error("LoadRefIssue(%d): %v", c.RefCommentID, err)
return ""
}
- return c.RefIssue.HTMLURL()
+ return c.RefIssue.Link()
}
// RefIssueTitle returns the title of the issue where this reference was created